==> gcli_2.1.0.orig.tar.gz: gcli-2.1.0/src/gitea/sshkeys.c <==
/*
 * Copyright 2023 Nico Sonack <nsonack@herrhotzenplotz.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <gcli/gitea/sshkeys.h>
#include <gcli/json_util.h>

/* NOTE(Nico): The APIs of all the three forges we currently implement
 *             are the same. Thus, we just call into the gitlab
 *             implementation. Yes, this looks absurd. */

#include <gcli/gitlab/sshkeys.h>

int
gitea_get_sshkeys(gcli_ctx *ctx, gcli_sshkey_list *list)
{
	return gitlab_get_sshkeys(ctx, list);
}

int
gitea_add_sshkey(gcli_ctx *ctx, char const *const title,
                 char const *const pubkey, gcli_sshkey *const out)
{
	return gitlab_add_sshkey(ctx, title, pubkey, out);
}

int
gitea_delete_sshkey(gcli_ctx *ctx, gcli_id const id)
{
	return gitlab_delete_sshkey(ctx, id);
}

==> gcli_2.9.1.orig.tar.gz: gcli-2.9.1/src/gitea/sshkeys.c <==
/*
 * Copyright 2023 Nico Sonack <nsonack@herrhotzenplotz.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <gcli/gitea/sshkeys.h>
#include <gcli/json_util.h>

/* NOTE(Nico): The APIs of all the three forges we currently implement
 *             are the same. Thus, we just call into the gitlab
 *             implementation. Yes, this looks absurd. */

#include <gcli/gitlab/sshkeys.h>

int
gitea_get_sshkeys(struct gcli_ctx *ctx, struct gcli_sshkey_list *list)
{
	return gitlab_get_sshkeys(ctx, list);
}

int
gitea_add_sshkey(struct gcli_ctx *ctx, char const *const title,
                 char const *const pubkey, struct gcli_sshkey *const out)
{
	return gitlab_add_sshkey(ctx, title, pubkey, out);
}

int
gitea_delete_sshkey(struct gcli_ctx *ctx, gcli_id const id)
{
	return gitlab_delete_sshkey(ctx, id);
}
